Package: likert
Type: Package
Title: Analysis and Visualization Likert Items
Version: 1.3.5.1
Date: 2016-12-29
Authors@R: c(person(given = "Jason",
                    family = "Bryer",
                    role = c("aut", "cre"),
                    email = "jason@bryer.org"),
             person(given = "Kimberly",
                    family = "Speerschneider",
                    role = "aut",
                    email = "kimkspeer@gmail.com"))
URL: https://github.com/jbryer/likert
BugReports: https://github.com/jbryer/likert/issues
Description: An approach to analyzing Likert response items, with an emphasis on visualizations. 
    The stacked bar plot is the preferred method for presenting Likert results. Tabular results
    are also implemented along with density plots to assist researchers in determining whether 
    Likert responses can be used quantitatively instead of qualitatively. See the likert(), 
    summary.likert(), and plot.likert() functions to get started.
License: GPL
LazyLoad: yes
VignetteBuilder: utils
Depends: R (>= 3.0),ggplot2,xtable
Imports: psych,reshape2,gridExtra,grid,plyr
Suggests: devtools,shiny
RoxygenNote: 7.3.2
NeedsCompilation: no
Packaged: 2025-08-02 07:59:45 UTC; hornik
Repository: CRAN
Date/Publication: 2025-08-02 08:02:55 UTC
Author: Jason Bryer [aut, cre],
  Kimberly Speerschneider [aut]
Maintainer: Jason Bryer <jason@bryer.org>
Built: R 4.6.0; ; 2026-04-28 01:06:16 UTC; unix
