# Generated by roxygen2: do not edit by hand

S3method(plot,likert)
S3method(plot,likert.gap)
S3method(print,likert)
S3method(print,likert.bar.plot)
S3method(print,likert.gap)
S3method(print,xlikert)
S3method(summary,likert)
S3method(summary,likert.gap)
S3method(xtable,likert)
export(likert)
export(likert.bar.plot)
export(likert.density.plot)
export(likert.heat.plot)
export(likert.histogram.plot)
export(likert.options)
export(recode)
export(reverse.levels)
import(ggplot2)
import(gridExtra)
import(reshape2)
import(xtable)
importFrom(grDevices,colorRamp)
importFrom(grDevices,rgb)
importFrom(graphics,hist)
importFrom(graphics,lines)
importFrom(graphics,pairs)
importFrom(graphics,par)
importFrom(graphics,rect)
importFrom(graphics,strwidth)
importFrom(graphics,symbols)
importFrom(graphics,text)
importFrom(grid,editGrob)
importFrom(grid,gTree)
importFrom(grid,getGrob)
importFrom(grid,grid.draw)
importFrom(grid,grid.layout)
importFrom(grid,grid.newpage)
importFrom(grid,grob)
importFrom(grid,grobHeight)
importFrom(grid,grobWidth)
importFrom(grid,pushViewport)
importFrom(grid,upViewport)
importFrom(grid,viewport)
importFrom(grid,vpPath)
importFrom(grid,vpTree)
importFrom(plyr,llply)
importFrom(psych,describe)
importFrom(psych,describeBy)
importFrom(stats,cor)
importFrom(stats,cor.test)
importFrom(stats,density)
importFrom(stats,sd)
importFrom(stats,symnum)
importFrom(utils,packageVersion)
